@@ -6,7 +6,7 @@ plat=x86_64
 
 # install MeCab
 # TODO specify the commit used here
-git clone --depth=1 git://github.com/taku910/mecab.git
+git clone --depth=1 https://github.com/taku910/mecab.git
 cd mecab/mecab
 if [ `uname -m` == 'aarch64' ]; then
   manylinux_version=2014
@@ -25,7 +25,7 @@ make install
 export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/usr/local/lib/
 
 # Build the wheels
-for PYVER in cp36-cp36m cp37-cp37m cp38-cp38 cp39-cp39 cp310-cp310; do
+for PYVER in cp37-cp37m cp38-cp38 cp39-cp39 cp310-cp310; do
   # build the wheels
   /opt/python/$PYVER/bin/pip wheel /github/workspace -w /github/workspace/wheels || { echo "Failed while buiding $PYVER wheel"; exit 1; }
 done
